import { StyleSheet, Text, View, ScrollView, FlatList, TouchableWithoutFeedback } from 'react-native'
import { useState } from 'react'
import fonts from '../theme/fonts'
import colors from '../theme/colors'
import PrimaryButton from '../components/organisms/Buttons/PrimaryButton'
import { Portal, ToggleButton, Modal, PaperProvider, IconButton } from 'react-native-paper'
import NewscoutHomeHeader from '../components/organisms/Headers/NewscoutHomeHeader'
import ThemedTextButton from '../components/organisms/Buttons/ThemedTextButton'
import RecentPostsSection from '../components/organisms/Sections/RecentPostsSection'
import TrendingSection from '../components/organisms/Sections/TrendingSection'
import CategorySection from '../components/organisms/Sections/CategorySection'
import CloseButton from '../components/organisms/Buttons/CloseButton'


const UnsignedLandingPage = ({ navigation }) => {

    const categories = ["All", "Tech", "Banking", "Retail", "Politics"]
    const news = [{}, {}, {}, {}, {}, {}, {}]
    const [categoryValue, setCategoryValue] = useState('all')

    const [visible, setVisible] = useState(false);
    const showModal = () => setVisible(true);
    const hideModal = () => setVisible(false);

    // For Login prompt
    const [isDimissed, setDismissed] = useState(false);

    const homePageNavigation = () => {
        navigation.navigate('Home')
    }

    return (
        <PaperProvider>


            <View style={styles.container}>
                <Portal>
                    <Modal visible={visible} onDismiss={hideModal} contentContainerStyle={styles.modalContainerStyle}>
                        <IconButton
                            icon="close"
                            iconColor={colors.black}
                            size={16}
                            onPress={hideModal}
                            style={{ alignSelf: 'flex-end' }}
                        />
                        <Text
                            style={{
                                fontFamily: fonts.type.regular,
                                color: colors.black,
                                fontSize: fonts.getSize(14),
                                paddingTop: fonts.getSize(8),
                                paddingBottom: fonts.getSize(16)
                            }}
                        >
                            You are not logged in. Log in to bookmark news, leave comment and to explore more!
                        </Text>
                        <ThemedTextButton title="Login" onPress={homePageNavigation} theme={"secondary-contained"} />
                        <View style={{ flexDirection: 'row', justifyContent: 'center', alignItems: 'center', paddingVertical: fonts.getSize(16) }}>
                            <Text
                                style={{
                                    color: colors.black,
                                    fontFamily: fonts.type.regular
                                }}
                            >Don’t have account? </Text>
                            <TouchableWithoutFeedback onPress={true}>
                                <Text
                                    style={{
                                        color: colors.secondaryColor,
                                        fontFamily: fonts.type.regular
                                    }}
                                >
                                    Create one
                                </Text>
                            </TouchableWithoutFeedback>
                        </View>
                    </Modal>
                </Portal>
                <ScrollView showsVerticalScrollIndicator={false}>

                    {
                        isDimissed === false ? <>
                            <NewscoutHomeHeader >
                                <CloseButton onPress={() => setDismissed(!isDimissed)} />
                            </NewscoutHomeHeader>
                            <Text style={styles.loginText}>You are not logged in. Sign in or log in to bookmark news leave comment and a lot more!</Text>
                            <View style={{ paddingHorizontal: 16 }}>
                                <ThemedTextButton theme={'secondary'} title={"Login"} onPress={showModal} />
                            </View>
                        </> : <NewscoutHomeHeader />


                    }
                    <TrendingSection />
                    <CategorySection />
                    <RecentPostsSection />

                    {/* <View style={styles.underlinePillContainer}>
                    <ScrollView horizontal showsHorizontalScrollIndicator={false}>
                        <ToggleButton.Group onValueChange={value => setCategoryValue(value)}>
                            {
                                categories.map((category) => {
                                    let valueId = category.toLowerCase()
                                    return <ToggleButton
                                        icon={() =>
                                            <Text style={
                                                [
                                                    valueId === categoryValue ?
                                                        styles.selectedPillText :
                                                        styles.pillText,
                                                    {
                                                        paddingHorizontal: fonts.getSize(11),
                                                        fontSize: fonts.getSize(16)
                                                    }
                                                ]
                                            }>
                                                {category}
                                            </Text>}
                                        style={[styles.underlinePill]}
                                        value={valueId}
                                    />
                                })
                            }
                        </ToggleButton.Group>
                    </ScrollView>
                </View>
                <FlatList
                    showsVerticalScrollIndicator={false}
                    ItemSeparatorComponent={() => <View style={{ height: fonts.getSize(8) }}></View>}
                    // ListFooterComponent={() => <View style={{height: fonts.getSize(16)}}></View>}
                    ListHeaderComponent={() => <View style={{ height: fonts.getSize(16) }}></View>}
                    data={news}
                    renderItem={(item) => <HorizontalNewsCardVariant onPress={true} />}
                    keyExtractor={item => news.indexOf(item)}

                /> */}
                </ScrollView>

            </View>

        </PaperProvider>
    )
}


export default UnsignedLandingPage

const styles = StyleSheet.create({
    container: {
        backgroundColor: colors.white,
        paddingBottom: 16
    },
    loginText: {
        fontFamily: fonts.type.regular,
        padding: 16,
        color: colors.black
    },
    underlinePillContainer: {
        paddingVertical: 8,
        flexDirection: 'row',
        alignItems: 'space-between',

    },
    selectedPillText: {
        fontFamily: fonts.type.semibold,
        fontSize: fonts.getSize(12),
        color: colors.black,
        borderBottomWidth: fonts.getSize(4),
        borderBottomColor: colors.tertiaryColor,
        borderRadius: 0


    },
    pillText: {
        fontFamily: fonts.type.semibold,
        fontSize: fonts.getSize(12),
        color: colors.gray
    },
    underlinePill: {
        width: 'auto',
    },
    cardContainer: {
        gap: fonts.getSize(4),
        paddingVertical: fonts.getSize(4)
    },
    modalContainerStyle: {
        padding: fonts.getSize(16),
        width: 'auto',
        marginHorizontal: fonts.getSize(32),
        backgroundColor: colors.white,
        borderRadius: fonts.getSize(4)
    }
})